==> peony_4.10.0.0.orig.tar.gz: peony-4.10.0.0/translations/peony-qt-desktop/peony-qt-desktop_cs.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="cs">
<context>
    <name>Peony::DesktopIconView</name>
    <message>
        <location filename="../../peony-qt-desktop/desktop-icon-view.h" line="81"/>
        <source>Desktop Icon View</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-icon-view.cpp" line="631"/>
        <source>New Folder</source>
        <translation type="unfinished">Yeni Klasör</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-icon-view.cpp" line="725"/>
        <source>set background</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-icon-view.cpp" line="950"/>
        <source>Open Link failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-icon-view.cpp" line="951"/>
        <source>File not exist, do you want to delete the link file?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-icon-view.cpp" line="967"/>
        <source>Open failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-icon-view.cpp" line="968"/>
        <source>Open directory failed, you have no permission!</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Peony::DesktopItemModel</name>
    <message>
        <location filename="../../peony-qt-desktop/desktop-item-model.cpp" line="624"/>
        <source>Computer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-item-model.cpp" line="626"/>
        <source>Trash</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Peony::DesktopMenu</name>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="237"/>
        <source>Reverse Select</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;New...</source>
        <translation type="vanished">&amp;Yeni...</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="338"/>
        <source>New Folder</source>
        <translation type="unfinished">Yeni Klasör</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="405"/>
        <source>Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="407"/>
        <source>File Type</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="408"/>
        <source>File Size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="406"/>
        <source>Modified Date</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="109"/>
        <source>Open in new Window</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="114"/>
        <source>Select All</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="137"/>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="165"/>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="199"/>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="210"/>
        <source>Open</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="145"/>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="170"/>
        <source>Open with...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="158"/>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="193"/>
        <source>More applications...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="213"/>
        <source>Open %1 selected files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="251"/>
        <source>New</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="322"/>
        <source>Empty File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="334"/>
        <source>Folder</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="357"/>
        <source>View Type</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="363"/>
        <source>Small</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="366"/>
        <source>Normal</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="369"/>
        <source>Large</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="372"/>
        <source>Huge</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="400"/>
        <source>Sort By</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="480"/>
        <source>Clean the trash</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="501"/>
        <source>Copy</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="505"/>
        <source>Cut</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="526"/>
        <source>Delete to trash</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="535"/>
        <source>Delete forever</source>
        <translation>Kalıcı olarak sil</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="543"/>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="548"/>
        <source>Rename</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="555"/>
        <source>Paste</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="562"/>
        <source>Refresh</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="576"/>
        <source>Properties</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>P&amp;roperties</source>
        <translation type="obsolete">Özellikler</translation>
    </message>
    <message>
        <source>Sort Order...</source>
        <translation type="vanished">Sıralama Düzeni...</translation>
    </message>
    <message>
        <source>Ascending Order</source>
        <translation type="vanished">Artan Düzen</translation>
    </message>
    <message>
        <source>Descending Order</source>
        <translation type="vanished">Azalan Düzen</translation>
    </message>
    <message>
        <source>Zoom &amp;In</source>
        <translation type="vanished">Yakınlaştır</translation>
    </message>
    <message>
        <source>Zoom &amp;Out</source>
        <translation type="vanished">Uzaklaştır</translation>
    </message>
    <message>
        <source>Cu&amp;t</source>
        <translation type="vanished">Kes</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation type="vanished">Sil</translation>
    </message>
    <message>
        <source>&amp;Rename</source>
        <translation type="vanished">Yeniden Adlandır</translation>
    </message>
    <message>
        <source>&amp;Properties</source>
        <translation type="vanished">Özellikler</translation>
    </message>
</context>
<context>
    <name>Peony::DesktopWindow</name>
    <message>
        <source>Desktop</source>
        <translation type="obsolete">Masaüstü</translation>
    </message>
    <message>
        <source>New Folder</source>
        <translation type="vanished">Yeni Klasör</translation>
    </message>
</context>
<context>
    <name>PeonyDesktopApplication</name>
    <message>
        <source>Close the peony-qt desktop window</source>
        <translation type="vanished">Masaüstünü kapatın ve çıkın</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/peony-desktop-application.cpp" line="226"/>
        <source>peony-qt-desktop</source>
        <translation>Masaüstü</translation>
    </message>
    <message>
        <source>Peony-Qt Desktop</source>
        <translation type="vanished">Masaüstü</translation>
    </message>
    <message>
        <source>Desktop</source>
        <translation type="vanished">Masaüstü</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/peony-desktop-application.cpp" line="560"/>
        <source>Close the peony desktop window</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/peony-desktop-application.cpp" line="563"/>
        <source>Take over the dbus service.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/peony-desktop-application.cpp" line="566"/>
        <source>Take over the desktop displaying</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/peony-desktop-application.cpp" line="569"/>
        <source>Setup backgrounds</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/peony-desktop-application.cpp" line="572"/>
        <source>Clear standard icons</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../../peony-qt-desktop/desktopbackgroundwindow.cpp" line="100"/>
        <source>set background</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktopbackgroundwindow.cpp" line="105"/>
        <source>display settings</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> peony_5.0.0.1.orig.tar.gz: peony-5.0.0.1/translations/peony-qt-desktop/peony-qt-desktop_cs.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="cs">
<context>
    <name>Peony::DesktopIconView</name>
    <message>
        <location filename="../../peony-qt-desktop/desktop-icon-view.h" line="89"/>
        <source>Desktop Icon View</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-icon-view.cpp" line="669"/>
        <source>New Folder</source>
        <translation type="unfinished">Yeni Klasör</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-icon-view.cpp" line="763"/>
        <source>Set Background</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-icon-view.cpp" line="1014"/>
        <source>Open Link failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-icon-view.cpp" line="1015"/>
        <source>File not exist, do you want to delete the link file?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-icon-view.cpp" line="1031"/>
        <source>Open failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-icon-view.cpp" line="1032"/>
        <source>Open directory failed, you have no permission!</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Peony::DesktopMenu</name>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="237"/>
        <source>Reverse Select</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;New...</source>
        <translation type="vanished">&amp;Yeni...</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="355"/>
        <source>New Folder</source>
        <translation type="unfinished">Yeni Klasör</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="422"/>
        <source>Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="424"/>
        <source>File Type</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="425"/>
        <source>File Size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="423"/>
        <source>Modified Date</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="109"/>
        <source>Open in new Window</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="114"/>
        <source>Select All</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="137"/>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="165"/>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="199"/>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="210"/>
        <source>Open</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="145"/>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="170"/>
        <source>Open with...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="158"/>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="193"/>
        <source>More applications...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="213"/>
        <source>Open %1 selected files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="251"/>
        <source>New</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="339"/>
        <source>Empty File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="351"/>
        <source>Folder</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="374"/>
        <source>View Type</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="380"/>
        <source>Small</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="383"/>
        <source>Normal</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="386"/>
        <source>Large</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="389"/>
        <source>Huge</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="417"/>
        <source>Sort By</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="497"/>
        <source>Clean the trash</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="518"/>
        <source>Copy</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="524"/>
        <source>Cut</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="545"/>
        <source>Delete to trash</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="554"/>
        <source>Delete forever</source>
        <translation>Kalıcı olarak sil</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="562"/>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="567"/>
        <source>Rename</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="574"/>
        <source>Paste</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="580"/>
        <source>Refresh</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="594"/>
        <source>Properties</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>P&amp;roperties</source>
        <translation type="obsolete">Özellikler</translation>
    </message>
    <message>
        <source>Sort Order...</source>
        <translation type="vanished">Sıralama Düzeni...</translation>
    </message>
    <message>
        <source>Ascending Order</source>
        <translation type="vanished">Artan Düzen</translation>
    </message>
    <message>
        <source>Descending Order</source>
        <translation type="vanished">Azalan Düzen</translation>
    </message>
    <message>
        <source>Zoom &amp;In</source>
        <translation type="vanished">Yakınlaştır</translation>
    </message>
    <message>
        <source>Zoom &amp;Out</source>
        <translation type="vanished">Uzaklaştır</translation>
    </message>
    <message>
        <source>Cu&amp;t</source>
        <translation type="vanished">Kes</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation type="vanished">Sil</translation>
    </message>
    <message>
        <source>&amp;Rename</source>
        <translation type="vanished">Yeniden Adlandır</translation>
    </message>
    <message>
        <source>&amp;Properties</source>
        <translation type="vanished">Özellikler</translation>
    </message>
</context>
<context>
    <name>Peony::DesktopWindow</name>
    <message>
        <source>Desktop</source>
        <translation type="obsolete">Masaüstü</translation>
    </message>
    <message>
        <source>New Folder</source>
        <translation type="vanished">Yeni Klasör</translation>
    </message>
</context>
<context>
    <name>PeonyDesktopApplication</name>
    <message>
        <source>Close the peony-qt desktop window</source>
        <translation type="vanished">Masaüstünü kapatın ve çıkın</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/peony-desktop-application.cpp" line="227"/>
        <source>peony-qt-desktop</source>
        <translation>Masaüstü</translation>
    </message>
    <message>
        <source>Peony-Qt Desktop</source>
        <translation type="vanished">Masaüstü</translation>
    </message>
    <message>
        <source>Desktop</source>
        <translation type="vanished">Masaüstü</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/peony-desktop-application.cpp" line="567"/>
        <source>Close the peony desktop window</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/peony-desktop-application.cpp" line="570"/>
        <source>Take over the dbus service.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/peony-desktop-application.cpp" line="573"/>
        <source>Take over the desktop displaying</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/peony-desktop-application.cpp" line="576"/>
        <source>Setup backgrounds</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/peony-desktop-application.cpp" line="579"/>
        <source>Clear standard icons</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../../peony-qt-desktop/desktopbackgroundwindow.cpp" line="100"/>
        <source>Set Background</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktopbackgroundwindow.cpp" line="105"/>
        <source>Display Settings</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
